==> haskell-crypto-api-0.13.3-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-api
version:              0.13.3
visibility:           public
id:                   crypto-api-0.13.3-L9US7GS3I02EI9rbQ94kVv
key:                  crypto-api-0.13.3-L9US7GS3I02EI9rbQ94kVv
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:
    Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)

stability:            stable
homepage:             https://github.com/TomMD/crypto-api
synopsis:             A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.

category:             Data, Cryptography
abi:                  65c4bb36d8e33ca4bc3650e26e48cfef
exposed:              True
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util

hidden-modules:       Crypto.CPoly
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-api-0.13.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-api-0.13.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-api-0.13.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-api
hs-libraries:         HScrypto-api-0.13.3-L9US7GS3I02EI9rbQ94kVv
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html:         /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-0.13.3-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-api
version:              0.13.3
visibility:           public
id:                   crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix
key:                  crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:
    Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)

stability:            stable
homepage:             https://github.com/TomMD/crypto-api
synopsis:             A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.

category:             Data, Cryptography
abi:                  2976d18aaae00645b7456bc5bc6af339
exposed:              True
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util

hidden-modules:       Crypto.CPoly
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-api-0.13.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-api-0.13.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-api-0.13.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-api
hs-libraries:         HScrypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html:         /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
